@@ -30,7 +30,7 @@ class PreprocessDatasets:
             dataset = dataset.capitalize()
         self.dataset = dataset
         self.input_dir = input_dir
-        self.api = "http://94.60.148.158/apidownload/"
+        self.api = "http://94.60.148.158:8086/apidownload/"
         self.top = top
         self.test_size = test_size
         self.sample_perc = sample_perc
